@@ -1,5 +1,5 @@
 /* This file is part of KCachegrind.
-   Copyright (c) 2008-2015 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
+   Copyright (c) 2008-2016 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
 
    KCachegrind is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -31,19 +31,19 @@
 
 void showHelp(QTextStream& out, bool fullHelp = true)
 {
-    out <<  "Show profiles from callgrind files. (c) 2010-2015 J. Weidendorfer\n";
+    out <<  "Show profiles from callgrind files. (c) 2010-2016 J. Weidendorfer\n";
 
     if (!fullHelp)
         out << "Type 'cgview -h' for help." << endl;
     else
         out << "Usage: cgview [options] <file> ...\n\n"
-            "Options:\n"
-            " -h        Show this help text\n"
-            " -e        Sort list according to exclusive cost\n"
-            " -s <ev>   Sort and show counters for event <ev>\n"
-            " -c        Sort by call count\n"
-            " -b        Show butterfly (callers and callees)\n"
-            " -n        Do not detect recursive cycles" << endl;
+               "Options:\n"
+               " -h        Show this help text\n"
+               " -e        Sort list according to exclusive cost\n"
+               " -s <ev>   Sort and show counters for event <ev>\n"
+               " -c        Sort by call count\n"
+               " -b        Show butterfly (callers and callees)\n"
+               " -n        Do not detect recursive cycles" << endl;
 
     exit(1);
 }
@@ -69,12 +69,12 @@ int main(int argc, char** argv)
     QStringList files;
 
     for(int arg = 0; arg<list.count(); arg++) {
-        if      (list[arg] == "-h") showHelp(out);
-        else if (list[arg] == "-e") sortByExcl = true;
-        else if (list[arg] == "-n") GlobalConfig::setShowCycles(false);
-        else if (list[arg] == "-b") showCalls = true;
-        else if (list[arg] == "-c") sortByCount = true;
-        else if (list[arg] == "-s") showEvent = list[++arg];
+        if      (list[arg] == QLatin1String("-h")) showHelp(out);
+        else if (list[arg] == QLatin1String("-e")) sortByExcl = true;
+        else if (list[arg] == QLatin1String("-n")) GlobalConfig::setShowCycles(false);
+        else if (list[arg] == QLatin1String("-b")) showCalls = true;
+        else if (list[arg] == QLatin1String("-c")) sortByCount = true;
+        else if (list[arg] == QLatin1String("-s")) showEvent = list[++arg];
         else
             files << list[arg];
     }
@@ -84,15 +84,14 @@ int main(int argc, char** argv)
     EventTypeSet* m = d->eventTypes();
     if (m->realCount() == 0) {
         out << "Error: No event types found." << endl;
-	return 1;
+        return 1;
     }
 
     out << "\nTotals for event types:\n";
 
-    QString p;
     EventType* et;
     for (int i=0;i<m->realCount();i++) {
-	et = m->realType(i);
+        et = m->realType(i);
         out.setFieldWidth(14);
         out.setFieldAlignment(QTextStream::AlignRight);
         out << d->subCost(et).pretty();
@@ -100,13 +99,13 @@ int main(int argc, char** argv)
         out << "   " << et->longName() << " (" << et->name() << ")\n";
     }
     for (int i=0;i<m->derivedCount();i++) {
-	et = m->derivedType(i);
+        et = m->derivedType(i);
         out.setFieldWidth(14);
         out.setFieldAlignment(QTextStream::AlignRight);
         out << d->subCost(et).pretty();
         out.setFieldWidth(0);
         out << "   " << et->longName() <<
-                " (" << et->name() << " = " << et->formula() << ")\n";
+               " (" << et->name() << " = " << et->formula() << ")\n";
     }
     out << endl;
 
@@ -121,7 +120,7 @@ int main(int argc, char** argv)
     }
     Q_ASSERT( et!=0 );
     out << "Sorted by: " << (sortByExcl ? "Exclusive ":"Inclusive ")
-            << et->longName() << " (" << et->name() << ")" << endl;
+        << et->longName() << " (" << et->name() << ")" << endl;
 
     QList<TraceFunction*> flist;
     HighestCostList hc;
@@ -149,7 +148,7 @@ int main(int argc, char** argv)
 
     out.setFieldAlignment(QTextStream::AlignRight);
     for(int i=0; i<hc.realCount(); i++) {
-	f = (TraceFunction*)hc[i];
+        f = (TraceFunction*)hc[i];
 
         if (showCalls) {
             if (i>0) out << endl;
